about summary refs log tree commit diff
path: root/src/libextra
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2014-02-18 02:51:49 -0800
committerbors <bors@rust-lang.org>2014-02-18 02:51:49 -0800
commitb3ed38f2196e8636f9f295da8d06c6921db183fe (patch)
tree02968a54be00a4a213dece5f5900230809ce7f5a /src/libextra
parent1e60084257ca6f264610544964bf553f1feba83b (diff)
parent6555b04dd2fbcd18c8fa8beb2bebc4b81febc6b0 (diff)
downloadrust-b3ed38f2196e8636f9f295da8d06c6921db183fe.tar.gz
rust-b3ed38f2196e8636f9f295da8d06c6921db183fe.zip
auto merge of #12345 : huonw/rust/speeling, r=cmr
Diffstat (limited to 'src/libextra')
-rw-r--r--src/libextra/json.rs10
-rw-r--r--src/libextra/test.rs2
2 files changed, 6 insertions, 6 deletions
diff --git a/src/libextra/test.rs b/src/libextra/test.rs
index 8d85dc9b6ff..fe397c30ab5 100644
--- a/src/libextra/test.rs
+++ b/src/libextra/test.rs
@@ -1110,7 +1110,7 @@ impl MetricMap {
 
 // Benchmarking
 
-/// A function that is opaque to the optimiser, to allow benchmarks to
+/// A function that is opaque to the optimizer, to allow benchmarks to
 /// pretend to use outputs to assist in avoiding dead-code
 /// elimination.
 ///
diff --git a/src/libextra/json.rs b/src/libextra/json.rs
index 4c6cd4218e7..edf5bb63b30 100644
--- a/src/libextra/json.rs
+++ b/src/libextra/json.rs
@@ -125,7 +125,7 @@ fn main() {
 }
 ```
 
-To decode a json string using `Decodable` trait :
+To decode a JSON string using `Decodable` trait :
 
 ```rust
 extern crate serialize;
@@ -172,7 +172,7 @@ fn main() {
          {data_int: 1, data_str:~"toto", data_vector:~[2,3,4,5]};
     let encoded_str: ~str = json::Encoder::str_encode(&to_encode_object);
 
     // To unserialize use the `extra::json::from_str` and `extra::json::Decoder`
 
     let json_object = extra::json::from_str(encoded_str);
     let mut decoder = json::Decoder::new(json_object.unwrap());
@@ -182,7 +182,7 @@ fn main() {
 
 ## Using `ToJson`
 
-This example use the ToJson impl to unserialize the json string.
+This example use the ToJson impl to deserialize the JSON string.
 Example of `ToJson` trait implementation for TestStruct1.
 
 ```rust
@@ -212,13 +212,13 @@ impl ToJson for TestStruct1 {
 }
 
 fn main() {
-    // Seralization using our impl of to_json
+    // Serialization using our impl of to_json
 
     let test2: TestStruct1 = TestStruct1 {data_int: 1, data_str:~"toto", data_vector:~[2,3,4,5]};
     let tjson: json::Json = test2.to_json();
     let json_str: ~str = tjson.to_str();
 
     // Unserialize like before.
 
     let mut decoder = json::Decoder::new(json::from_str(json_str).unwrap());
     // create the final object
@@ -172,7 +172,7 @@ fn main() {
     let encoded_str: ~str = json::Encoder::str_encode(&to_encode_object);
 
-    // To unserialize use the `extra::json::from_str` and `extra::json::Decoder`
+    // To deserialize use the `extra::json::from_str` and `extra::json::Decoder`
 
     let json_object = extra::json::from_str(encoded_str);
@@ -212,13 +212,13 @@ impl ToJson for TestStruct1 {
     let json_str: ~str = tjson.to_str();
 
-    // Unserialize like before.
+    // Deserialize like before.
 
     let mut decoder = json::Decoder::new(json::from_str(json_str).unwrap());